Learn R Programming

mregions2 (version 1.1.2)

gaz_rest_records_by_lat_long: Get all gazetteer records where the geometry intersects with the given latitude and longitude

Description

Get all gazetteer records where the geometry intersects with the given latitude and longitude

Usage

gaz_rest_records_by_lat_long(
  latitude,
  longitude,
  with_geometry = FALSE,
  typeid = NULL
)

Value

A data frame with Gazetteer entries

Arguments

latitude

(double) A decimal number which ranges from -90 to 90. Coordinates are assumed to be in WGS84

longitude

(double) A decimal number which ranges from -180 to 180. Coordinates are assumed to be in WGS84

with_geometry

(logical) Add geometries to the result data frame? Default = FALSE

typeid

(numeric) Restrict to one or more placetypeIDs. Retrieve a list of placetypeIDs with gaz_rest_types()

See Also

gaz_rest

Examples

Run this code
# \donttest{
gaz_rest_records_by_lat_long(51.21551, 2.927)
gaz_rest_records_by_lat_long(51.21551, 2.927,
                             with_geometry = TRUE,
                             typeid = c(255, 259))
# }

Run the code above in your browser using DataLab