"rdf": Geometry as an object of class 'rdf". See 'rdflib'
Default is "sfc"
multipart
(logical) Some Geo-Objects are compound of more than one part.
If FALSE, returns singlepart geometries (e.g. POLYGON, LINESTRING)
If TRUE (default), returns multipart geometries (e.g. MULTIPOLYGON, MULTILINESTRING)
Details
You can pass the output of most gaz_* functions to gaz_geometry() to retrieve the
geometry the gazetteer entry. The data frame is then transformed into a sf::sf object.
Developer info
This is done in the method gaz_geometry.mr_df(). mr_df is a class defined in
this package to ensure the data frame passed to gaz_geometry has a variable with MRGID.