Learn R Programming

mregions2 (version 1.1.2)

gaz_rest: Marine Regions Gazetteer RESTful services (Documentation)

Description

RESTful service REST (REpresentational State Transfer) is a simple stateless architecture that generally runs over HTTP.

mregions2 makes use of the RESTful API created and maintained by Marine Regions. The functions with names starting as gaz_rest_* perform HTTP requests to read the Marine Regions REST API. They are closer to the definition of each function in the Marine Regions REST API. All the gazetteer functions such as gaz_search()or gaz_relations() make use of these gaz_rest_* functions.

Arguments

Value

Returns a help page: gaz_rest is not a function but documentation.

See Also

gaz_rest_geometries(), gaz_rest_names_by_mrgid(), gaz_rest_record_by_mrgid(), gaz_rest_records_by_lat_long(), gaz_rest_records_by_name(), gaz_rest_records_by_names(), gaz_rest_records_by_source(), gaz_rest_records_by_type(), gaz_rest_relations_by_mrgid(), gaz_rest_sources(), gaz_rest_source_by_sourceid(), gaz_rest_types(), gaz_rest_wmses()

Examples

Run this code
?gaz_rest

Run the code above in your browser using DataLab