Learn R Programming

mregions2 (version 1.1.2)

gaz_rest_source_by_sourceid: Get the name of a source by providing a sourceID

Description

Get the name of a source by providing a sourceID

Usage

gaz_rest_source_by_sourceid(sourceid)

Value

a named vector with the source name and, if available, the url to the source.

Arguments

sourceid

(integer) A valid sourceID

See Also

gaz_rest, gaz_sources()

Examples

Run this code
# \donttest{
gaz_rest_source_by_sourceid(390)
gaz_rest_source_by_sourceid(657)
# }

Run the code above in your browser using DataLab