powered by
Get the name of a source by providing a sourceID
gaz_rest_source_by_sourceid(sourceid)
a named vector with the source name and, if available, the url to the source.
(integer) A valid sourceID
gaz_rest, gaz_sources()
gaz_sources()
# \donttest{ gaz_rest_source_by_sourceid(390) gaz_rest_source_by_sourceid(657) # }
Run the code above in your browser using DataLab