Learn R Programming

mregions2 (version 1.1.2)

gaz_types: Get all the place types of the Marine Regions Gazetteer

Description

Get all the place types of the Marine Regions Gazetteer

Usage

gaz_types()

Arguments

Value

a data frame with three columns:

  • typeID: the identifier of the place type in the Marine Regions Gazetteer database.

  • type: the name of the place type.

  • description: if available, the description of the place type.

See Also

gaz_rest

Examples

Run this code
# \donttest{
# This
gaz_rest_types()

# is the same as
gaz_types()
# }

Run the code above in your browser using DataLab