powered by
Get all the place types of the Marine Regions Gazetteer
gaz_types()
a data frame with three columns:
typeID: the identifier of the place type in the Marine Regions Gazetteer database.
typeID
type: the name of the place type.
type
description: if available, the description of the place type.
description
gaz_rest
# \donttest{ # This gaz_rest_types() # is the same as gaz_types() # }
Run the code above in your browser using DataLab