mrp_col_unique: Get all the possible values of a column of a Marine Regions data product
Description
Get all the possible values of a column of a Marine Regions data product
Usage
mrp_col_unique(layer, colname)
mrp_col_distinct(layer, colname)
Value
A numeric or character vector with the unique values of a column of a Marine Regions data product.
Arguments
layer
(character) Identifier of the data product. See mrp_list
colname
(character) Column name in the data product. See mrp_colnames()
Details
This function becomes useful to write CQL or OGC filters that you can pass to mrp_get() or mrp_view() as
it helps to know all the possible values in the column name that you want to query on beforehand. Use it
together with mrp_colnames() to know the columns and data types in the data product.
Geometry columns
Note that columns of type geometry are forbidden as their performance is sub-optimal and would likely
crash your R session.
See Also
mrp_list to describe the list of products, mrp_colnames() to get the names and data type of
the columns of a data product, useful to write queries that can be passed to mrp_get() or mrp_view() via
the arguments cql_filter or filter.