mrp_colnames: Get the names of the columns and data type of the data product
Description
Get the names of the columns and data type of the data product
Usage
mrp_colnames(layer)
Value
A data frame with the column names and data type in the Marine Regions data product
Arguments
layer
(character) Identifier of the data product. See mrp_list
Details
This function becomes useful to write CQL or OGC filters that you can pass to mrp_get() or mrp_view() as
it allows you to know the column names and the data types beforehand. Use it together with mrp_col_unique() to
know all the possible values in the column name that you want to query on.
mrp_list to describe the list of products, mrp_col_unique() to get the unique values of a the
columns of a data product, useful to write queries that can be passed to mrp_get() or mrp_view() via the
arguments cql_filter or filter.