Learn R Programming

mregions2 (version 1.1.2)

mrp_list: Available data products at Marine Regions

Description

A data frame including the name, abstract and some other relevant about each data product in Marine Regions.

Usage

mrp_list

Arguments

Format

mrp_list

A data frame with 21 rows and 7 columns:

title

Data product name

namespace

Workspace in geoserver

layer

Identifier of the data product. Use in mrp_get()

license

terms of use of the data products

citation

preferred citation of the data products

doi

ISO 26324 Digital Object Identifier)

imis

Url of the data products in the Integrated Marine Information System (IMIS)

abstract

Description of the data product

Details

Direct downloads are also available at: https://marineregions.org/downloads.php

Examples

Run this code
mrp_list

Run the code above in your browser using DataLab